#version 150

#moj_import <purple_border_gui/util_functions.glsl>
#moj_import <purple_border_gui/item_selection_bitmap.glsl>

in vec3 Position;
in vec4 Color;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;

out vec4 vertexColor;
out vec4 gradientColor;
out vec4 gradientResolution;
out float renderSlotHighlight;
out vec3 cornerPos1;
out vec3 cornerPos2;
out vec3 cornerPos3;
out vec3 pos;

void main() {
    pos = Position;
    renderSlotHighlight = 0;
    int id = gl_VertexID % 4;
    
    cornerPos1 = cornerPos2 = cornerPos3 = vec3(0);
    switch (id) {
        case 0: cornerPos1 = vec3(pos.xy,1); break;
        case 1: cornerPos2 = vec3(pos.xy,1); break;
        case 2: cornerPos3 = vec3(pos.xy,1); break;
    }

    vertexColor = Color;

    gradientColor = vec4(0);
    gradientResolution = vec4(0);
    if(id == 1 || id == 2) { gradientColor.r = 1; } else { gradientColor.r = 0; } // vertical
    if(id == 2 || id == 3) { gradientColor.g = 1; } else { gradientColor.g = 0; } // horizontal

    if(Position.z == 0 && ProjMat[3][0] == -1){
        // world/resourcepack highlight
        if( roughlyEquals( Color, vec4(0.56471, 0.56471, 0.56471, 0.62745) ) ) {
            vertexColor = vec4(0.7412, 0.2824, 0.7176, 0.367);
        }
        // classic style tooltip (transparent black square)
        else if( roughlyEquals( Color, vec4(0, 0, 0, 0.75294 ) ) ) {
            vertexColor = vec4(0.72157, 0.38824, 0.10196, 0.4);
        }
        // social interactions player background thing
        else if( roughlyEquals( Color, vec4(0.2902, 0.2902, 0.2902, 1) ) ) {
            vertexColor.rgb = vec3(0.12941, 0.04314, 0.12549);
        }
    }
    // tooltip
    else if (ProjMat[3][0] == -1) {
        // tooltip top
        if( roughlyEquals(Color, vec4(0.31373, 0, 1, 0.31373) ) ) {
            vertexColor = vec4(0.98824, 0.83137, 0.39608, 1);
        }
        // tooltip bottom
        else if( roughlyEquals(Color, vec4(0.15686, 0, 0.49804, 0.31373) ) ) {
            vertexColor = vec4(0.72157, 0.38824, 0.10196, 1);
        }
        // tooltip background
        else if( roughlyEquals(Color, vec4(0.06275, 0, 0.06275, 0.94118) ) ) {
            vertexColor = vec4(0.6, 0.3176, 0.0824, 0.6);
        }
    }

    // right click highlight
    if( roughlyEquals( Color, vec4(1, 1, 1, 0.50196) ) && Position.z == 100  ) {
        float expandSize = (SECOND_BITMAP_SIZE - 16) / 2;
        float resolution = SECOND_BITMAP_SIZE;

        // expand quad size
        if(id == 1 || id == 2) { pos.y -= expandSize; } else { pos.y += expandSize; } // vertical
        if(id == 2 || id == 3) { pos.x -= expandSize; } else { pos.x += expandSize; } // horizontal
        // gradient
        if(id == 1 || id == 2) { gradientColor.r = 0; } else { gradientColor.r = 1; } // vertical
        if(id == 2 || id == 3) { gradientColor.g = 0; } else { gradientColor.g = 1; } // horizontal

        renderSlotHighlight = 3;

        gradientResolution.xy = vec2(resolution);
        
        vertexColor = vec4(0.9882, 0.8314, 0.3961, 0.26);
    }
    
    gl_Position = ProjMat * ModelViewMat * vec4(pos, 1.0);
}
